function [vK, vi, V, p1] = avf(QK, Qi, u, beta)

%% AVF calculates choice probabilities and value functions for a dynamic 
% discrete choice model as in Abbring and Daljord (2017)
%
% [vK, vi, V, p1] = AVF(QK, Qi, u, beta) computes ....
% for a dynamic discrete choice model with
%       QK - K x (K-1) matrix with the first K-1 columns of Q_K
%       Qi - L x (K-1) matrix with first L<=K rows and K-1 columns of Q_i 
%       u - colomn vector of utilities
%       beta - scalar discount factor

% Complete transitions
Qi = [Qi 1-sum(Qi,2)]; 
QK = [QK 1-sum(QK,2)];

% Set parameters
J = length(QK); 

% Start iterations somewhere
vK = rand(J,1); 
vi = rand(J,1);
vKnew = zeros(J,1); 
vinew = zeros(J,1); 


% Initialize and iterate until convergence
it = 0;
crit = 1;
iterationlimit = 10000; 

while crit > 10^(-14)
    vK = vKnew; 
    vi = vinew; 
    V = log(exp(vi) + exp(vK)); 
    vinew = u + beta*Qi*V; 
    vKnew = beta*QK*V; 
    crit = max(max(abs([vK-vKnew, vi-vinew]))); 
    it = it +1; 
    if it > iterationlimit
        fprintf('Failed to converge in %d iterations \n \n', iterationlimit); 
        break
    end
end
if it < iterationlimit
    fprintf('Converged in %d iterations \n \n ', it)
end

% Probabilities
p1 = exp(vi - vK)./(1 + exp(vi - vK));